@@ -92,6 +92,7 @@ public:
 
   const cimg_library::CImg<float> & previewImage() const;
   const QStringList & gmicStatus() const;
+  const QList<int> & parametersVisibilityStates() const;
 
   void saveSettings(QSettings & settings);
   ~GmicProcessor();
@@ -127,7 +128,7 @@ private slots:
 private:
   void updateImageNames(cimg_library::CImgList<char> & imageNames);
   void abortCurrentFilterThread();
-  void manageSynchonousRunner(FilterSyncRunner & thread);
+  void manageSynchonousRunner(FilterSyncRunner & runner);
 
   FilterThread * _filterThread;
   FilterContext _filterContext;
@@ -137,6 +138,7 @@ private:
 
   unsigned int _previewRandomSeed;
   QStringList _gmicStatus;
+  QList<int> _parametersVisibilityStates;
   QTimer _waitingCursorTimer;
   static const int WAITING_CURSOR_DELAY = 200;
 
