@@ -48,15 +48,8 @@
 #ifndef _STILLIMAGESOURCE_H_
 #define _STILLIMAGESOURCE_H_
 
-#if defined(HAS_OPENCV2_HEADERS) || defined(OPENCV2_HEADERS)
-#include <opencv2/core/core_c.h>
-#include <opencv2/highgui/highgui_c.h>
-#else
-#include <cv.h>
-#include <highgui.h>
-#endif
-#include "ImageSource.h"
 #include <QString>
+#include "ImageSource.h"
 
 class StillImageSource : public ImageSource {
 
@@ -67,6 +60,7 @@ public:
   bool loadImage(QString filename);
   const QString & filename() const;
   const QString & filePath() const;
+
 private:
   QString _filename;
   QString _filePath;
